# Sample Document

This is a **bold** statement with *emphasis* and ~~strikethrough~~ text.

Here's a paragraph with a [link to Rust](https://www.rust-lang.org/) and some `inline code`.

## Lists

Bullet list:
- First item
- Second item with **bold text**
  - Nested bullet item
  - Another nested item with *emphasis*
- Third item with `code`

Numbered list:
1. First numbered item
2. Second numbered item with [a link](https://github.com)
   1. Nested numbered item
   2. Another nested numbered item with ~~strikethrough~~
3. Third numbered item

## More Examples

Another paragraph with mixed *emphasis* and **strong** and `code` formatting.

Check out this [GitHub link](https://github.com) for more information.

### Additional Features

Testing paragraph breaks and line formatting.

This paragraph has `multiple inline code` segments and **bold formatting** mixed with *italic text*.

Testing ~~multiple~~ ~~strikethrough~~ elements in a single paragraph.